Installation
------------

Requirements
^^^^^^^^^^^^

xbudget is compatible with python 3 (>= version 3.11). It requires xgcm
(>= version 0.9.0).

Installation from Conda Forge
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

The easiest way to install xbudget along with its dependencies is via conda
forge::

    conda install -c conda-forge xbudget


Installation from Pip
^^^^^^^^^^^^^^^^^^^^^

An alternative is to use pip::

    pip install xbudget

This will install the latest release from
`pypi <https://pypi.python.org/pypi>`_.

Installation from GitHub
^^^^^^^^^^^^^^^^^^^^^^^^

xbudget is under active development. To obtain the latest development version,
you may clone the `source repository <https://github.com/hdrake/xbudget>`_
and install it using pip::

    pip install git+https://github.com/hdrake/xbudget.git

More comprehensive instructions for installing a development environment can be found in the Contributor Guide (coming soon).

Users are encouraged to `fork <https://help.github.com/articles/fork-a-repo/>`_
xbudget and submit issues_ and `pull requests`_.

.. _issues: https://github.com/hdrake/xbudget/issues
.. _`pull requests`: https://github.com/hdrake/xbudget/pulls